package com.zd.airbottle.service;

import java.util.List;
import com.zd.airbottle.domain.QpFlowDetail;
import com.zd.airbottle.domain.vo.QpFlowDetailVO;

/**
 * 气瓶流程详情Service接口
 *
 * @author zd
 * @date 2022-06-13
 */
public interface IQpFlowDetailService
{
    /**
     * 查询气瓶流程详情
     *
     * @param id 气瓶流程详情主键
     * @return 气瓶流程详情
     */
    QpFlowDetail selectQpFlowDetailById(Long id);

    /**
     * 查询气瓶流程详情列表
     *
     * @param qpFlowDetail 气瓶流程详情
     * @return 气瓶流程详情集合
     */
    List<QpFlowDetailVO> selectQpFlowDetailList(QpFlowDetailVO qpFlowDetail);

    /**
     * 根据主键集合查询气瓶流程详情列表
     *
     * @param ids 主键集合
     * @return 气瓶流程详情集合
     */
    List<QpFlowDetail> getListByIds(List<Long> ids);

    /**
     * 新增气瓶流程详情
     *
     * @param qpFlow 气瓶流程详情
     * @return 结果
     */
    int insertQpFlowDetail(QpFlowDetailVO qpFlow);

    /**
     * 修改气瓶流程详情
     *
     * @param qpFlowDetail 气瓶流程详情
     * @return 结果
     */
    int updateQpFlowDetail(QpFlowDetail qpFlowDetail);

    /**
     * 批量删除气瓶流程详情
     *
     * @param ids 需要删除的气瓶流程详情主键集合
     * @return 结果
     */
    int deleteQpFlowDetailByIds(Long[] ids);

    /**
     * 删除气瓶流程详情信息
     *
     * @param id 气瓶流程详情主键
     * @return 结果
     */
    int deleteQpFlowDetailById(Long id);

    /***
     * 实验中心-资格审核权限查询
     * @param userId
     * @return
     */
    QpFlowDetail selectZgCenterByUserIdIs(Long userId);

    /***
     * 实验中心-用气审核权限查询
     * @param userId
     * @return
     */
    QpFlowDetail selectYqCenterByUserIdIs(Long userId);
}
