package com.zd.airbottle.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.airbottle.domain.vo.QpFlowDetailVO;
import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.airbottle.domain.QpFlowDetail;
import com.zd.airbottle.service.IQpFlowDetailService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 气瓶流程详情Controller
 *
 * @author zd
 * @date 2022-06-13
 */
@RestController
@Api(tags = "【气瓶流程详情】")
@RequestMapping("/flowDetail")
public class QpFlowDetailController extends BaseController
{
    @Autowired
    private IQpFlowDetailService qpFlowDetailService;

    /**
     * 查询气瓶流程详情列表
     */
    @PreAuthorize(hasPermi = PerPrefix.AIRBOTTLE_FLOWDETAIL+ PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询气瓶流程详情列表")
    public TableDataInfo<QpFlowDetailVO> list(QpFlowDetailVO qpFlowDetail)
    {
        startPage("create_time","descending");
        List<QpFlowDetailVO> list = qpFlowDetailService.selectQpFlowDetailList(qpFlowDetail);
        return getDataTable(list);
    }

    /**
     * 导出气瓶流程详情列表
     */
    @ApiOperation(value = "导出气瓶流程详情列表")
    @PreAuthorize(hasPermi = PerPrefix.AIRBOTTLE_FLOWDETAIL+ PerFun.EXPORT)
    @Log(title = "气瓶流程详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QpFlowDetailVO qpFlowDetail) throws IOException
    {
        List<QpFlowDetailVO> list = qpFlowDetailService.selectQpFlowDetailList(qpFlowDetail);
        ExcelUtil<QpFlowDetailVO> util = new ExcelUtil<QpFlowDetailVO>(QpFlowDetailVO.class);
        util.exportExcel(response, list, "气瓶流程详情数据");
    }

    /**
     * 获取气瓶流程详情详细信息
     */
    @ApiOperation(value = "获取气瓶流程详情详细信息")
    @PreAuthorize(hasPermi = PerPrefix.AIRBOTTLE_FLOWDETAIL+ PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<QpFlowDetail> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(qpFlowDetailService.selectQpFlowDetailById(id));
    }

    /**
     * 新增气瓶流程详情
     */
    @ApiOperation(value = "新增气瓶流程详情")
    @PreAuthorize(hasPermi = PerPrefix.AIRBOTTLE_FLOWDETAIL+ PerFun.ADD)
    @Log(title = "气瓶流程详情", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody QpFlowDetailVO qpFlow)
    {
        return ResultData.result(qpFlowDetailService.insertQpFlowDetail(qpFlow));
    }

    /**
     * 修改气瓶流程详情
     */
    @ApiOperation(value = "修改气瓶流程详情")
    @PreAuthorize(hasPermi = PerPrefix.AIRBOTTLE_FLOWDETAIL+ PerFun.EDIT)
    @Log(title = "气瓶流程详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody QpFlowDetail qpFlowDetail)
    {
        return  ResultData.result(qpFlowDetailService.updateQpFlowDetail(qpFlowDetail));
    }

    /**
     * 删除气瓶流程详情
     */
    @ApiOperation(value = "删除气瓶流程详情")
    @PreAuthorize(hasPermi = PerPrefix.AIRBOTTLE_FLOWDETAIL+ PerFun.REMOVE)
    @Log(title = "气瓶流程详情", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(qpFlowDetailService.deleteQpFlowDetailByIds(ids));
    }
}
